@@ -369,7 +369,8 @@ class PhaseTracker(Term):
         for (start, end) in zip(start_dates, end_dates):
             param_dict = record_df.loc[end, parameters].to_dict()
             if end <= self._today:
-                y0_dict = record_df.loc[start, [self.S, self.CI, self.F, self.R]].to_dict()
+                ph_df = record_df.loc[start:, [self.S, self.CI, self.F, self.R]].reset_index()
+                y0_dict = self._model.convert(ph_df, self._tau).iloc[0].to_dict()
             else:
                 y0_dict = None
             _ = handler.add(end, param_dict=param_dict, y0_dict=y0_dict)
