@@ -5,8 +5,9 @@ import copy
 from datetime import timedelta
 import json
 from pathlib import Path
-import warnings
+import re
 import sys
+import warnings
 import numpy as np
 import pandas as pd
 from covsirphy.util.argument import find_args
@@ -23,6 +24,7 @@ from covsirphy.ode.sir import SIR
 from covsirphy.ode.sird import SIRD
 from covsirphy.ode.sirf import SIRF
 from covsirphy.regression.reg_handler import RegressionHandler
+from covsirphy.automl.automl_handler import AutoMLHandler
 from covsirphy.analysis.data_handler import DataHandler
 from covsirphy.analysis.phase_tracker import PhaseTracker
 
@@ -534,6 +536,22 @@ class Scenario(Term):
         self[name] = f[last_phase in phases or "last" in phases](start, end)
         return self
 
+    def delete_matched(self, pattern):
+        """
+        Delete scenarios which matchs to the given pattern.
+
+        Arg:
+            pattern (raw string): pattern to match
+
+        Returns:
+            covsirphy.Scenario: self
+        """
+        p = re.compile(pattern)
+        names = [name for name in self._tracker_dict.keys() if p.match(name)]
+        for name in names:
+            self.delete(name=name)
+        return self
+
     def _reverse(self, phases, name="Main"):
         """
         The status (enabled/disabled) will be reversed.
@@ -1005,7 +1023,7 @@ class Scenario(Term):
                     reset index
                 Columns
                     - Scenario (str)
-                    - Date (pandas.TimeStamp)
+                    - Date (pandas.Timestamp)
                     - Confirmed (int): the number of confirmed cases
                     - Infected (int): the number of currently infected cases
                     - Fatal (int): the number of fatal cases
@@ -1264,8 +1282,10 @@ class Scenario(Term):
         delay_period = int((low_lim + Q1) / 2)
         return (int(delay_period), df)
 
+    @deprecate("Scenario.fit()", new="Scenario.predict()", version="2.23.0-alpha", ref="https://github.com/lisphilar/covid19-sir/issues/1006")
     def fit(self, oxcgrt_data=None, name="Main", delay=(7, 31), removed_cols=None, metric="MAPE", **kwargs):
         """
+        Deprecated and merged to .predict().
         Fit regressors to predict the parameter values in the future phases,
         assuming that indicators will impact on ODE parameter values/the number of cases with delay.
         Please refer to covsirphy.RegressionHander class.
@@ -1374,6 +1394,9 @@ class Scenario(Term):
             metric (str): metric name, refer to covsirphy.Evaluator.score()
             show_figure (bool): whether show figure or not
             kwargs: keyword arguments of RegressionHandler.pred_true_plot()
+
+        Returns:
+            dict: this is the same as covsirphy.Regressionhander.to_dict()
         """
         metric = kwargs.pop("metrics") if "metrics" in kwargs else metric
         handler = self._get_fit_handler(name=name)
@@ -1381,46 +1404,62 @@ class Scenario(Term):
         if show_figure:
             handler.pred_actual_plot(
                 metric=metric, **find_args(RegressionHandler.pred_actual_plot, **kwargs))
+        # Return information
+        return handler.to_dict(metric=metric)
 
-    def predict(self, days=None, name="Main"):
+    def predict(self, days=30, method="multivariate_regression", name="Main", **kwargs):
         """
-        Predict parameter values of the future phases using Elastic Net regression with OxCGRT scores,
-        assuming that OxCGRT scores will impact on ODE parameter values with delay.
-        New future phases will be added (over-written).
+        Predict ODE parameter values with machine learning.
 
         Args:
-            days (list[int]): list of days to predict or None (only the max value)
+            days (int): days to predict
+            method (str): machine learning method name, refer to covsirphy.automl.automl_handler.AutoMLHandler.predict().
             name (str): scenario name
 
-        Raises:
-            covsirphy.UnExecutedError: Scenario.fit() was not performed
-            NotRegisteredExtraError: no extra datasets were registered
-
         Returns:
             covsirphy.Scenario: self
         """
-        handler = self._get_fit_handler(name=name)
-        # Prediction with regression model
-        df = handler.predict()
-        # -> index=end_date (pandas.Timestamp), columns=parameter values
-        df.index.name = "end_date"
-        # Days to predict
-        days = days or [len(df)]
-        self._ensure_list(days, candidates=list(range(1, len(df) + 1)), name="days")
-        phase_df = df.reset_index().loc[[day - 1 for day in days], :]
+        if days is None or isinstance(days, list):
+            return self.fit_predict(days=None, name="Main", **kwargs)
+        # ODE model
+        if self._model is None:
+            raise UnExecutedError(
+                "Scenario.estimate() or Scenario.add()",
+                message=f", specifying @model (covsirphy.SIRF etc.) and @name='{name}'.")
+        # Create X/Y
+        try:
+            X = self._data.records(main=True, extras=True).set_index(self.DATE)
+        except NotRegisteredExtraError:
+            X = self._data.records(main=True, extras=False).set_index(self.DATE)
+        tracker = self._tracker(name=name)
+        Y = tracker.track().set_index(self.DATE)
+        Y = Y.loc[Y.index <= self._data.today, self._model.PARAMETERS].dropna()
+        # Prediction
+        handler = AutoMLHandler(X, Y, model=self._model, days=days, **kwargs)
+        handler.predict(method=method)
+        phase_df = handler.summary()
+        phase_df = phase_df.rename(
+            columns={self.SERIES: "name", self.END: "end_date"}).drop([self.START, self.RT], axis=1)
+        phase_df = phase_df.sort_values(["name", "end_date"], ignore_index=True)
         # Set new future phases
         for phase_dict in phase_df.to_dict(orient="records"):
-            self.add(name=name, **phase_dict)
+            new_scenario = phase_dict["name"]
+            if new_scenario not in self._tracker_dict:
+                self.clear(name=new_scenario, template=name)
+            self.add(**phase_dict)
         return self
 
-    def fit_predict(self, oxcgrt_data=None, name="Main", **kwargs):
+    @deprecate("Scenario.fit_predict()", new="Scenario.predict()", version="2.23.0-alpha", ref="https://github.com/lisphilar/covid19-sir/issues/1006")
+    def fit_predict(self, oxcgrt_data=None, days=None, name="Main", **kwargs):
         """
+        Deprecated and renamed to .predict().
         Predict parameter values of the future phases using Elastic Net regression with OxCGRT scores,
         assuming that OxCGRT scores will impact on ODE parameter values with delay.
         New future phases will be added (over-written).
 
         Args:
             oxcgrt_data (covsirphy.OxCGRTData or None): OxCGRT dataset
+            days (list[int]): list of days to predict or None (only the max value)
             name (str): scenario name
             kwargs: the other arguments of Scenario.fit() and Scenario.predict()
 
@@ -1435,7 +1474,18 @@ class Scenario(Term):
             @oxcgrt_data argument was deprecated. Please use Scenario.register(extras=[oxcgrt_data]).
         """
         self.fit(oxcgrt_data=oxcgrt_data, name=name, **find_args(Scenario.fit, **kwargs))
-        self.predict(name=name, **find_args(Scenario.predict, **kwargs))
+        handler = self._get_fit_handler(name=name)
+        # Prediction with regression model
+        df = handler.predict()
+        # -> index=end_date (pandas.Timestamp), columns=parameter values
+        df.index.name = "end_date"
+        # Days to predict
+        days = days or [len(df)]
+        self._ensure_list(days, candidates=list(range(1, len(df) + 1)), name="days")
+        phase_df = df.reset_index().loc[[day - 1 for day in days], :]
+        # Set new future phases
+        for phase_dict in phase_df.to_dict(orient="records"):
+            self.add(name=name, **phase_dict)
         return self
 
     def backup(self, filename):
@@ -1455,8 +1505,8 @@ class Scenario(Term):
             },
             "scenario": {}
         }
-        for (name, trakcer) in self._tracker_dict.items():
-            summary_df = trakcer.summary()
+        for (name, tracker) in self._tracker_dict.items():
+            summary_df = tracker.summary()
             for col in [self.START, self.END]:
                 summary_df[col] = summary_df[col].dt.strftime(self.DATE_FORMAT)
             info_dict["scenario"][name] = summary_df.to_dict(orient="index")
@@ -1499,3 +1549,65 @@ class Scenario(Term):
                     add_dict["model"] = model_dict[model_name]
                 self.add(name=name, **add_dict)
         return self
+
+    def rename(self, old, new):
+        """
+        Rename the given scenario names with a new one.
+
+        Args:
+            old (str): old name
+            new (str): new name
+
+        Raises:
+            ScenarioNotFoundError: the old scenario does not exist
+            ValueError: the new scenario name has already exist
+
+        Returns:
+            covsirphy.Scenario: self
+        """
+        if old not in self._tracker_dict:
+            raise ScenarioNotFoundError(name=old)
+        if new in self._tracker_dict:
+            raise ValueError(f"@new={new}, but this scenario has already exist.")
+        self._tracker(name=new, template=old)
+        self._delete_series(name=old)
+        return self
+
+    def represent(self, q, variable, date=None, included=None, excluded=None):
+        """
+        Return the names of representative scenarios using quantiles of the variable on on the date.
+
+        Args:
+            q (list[float] or float): quantiles
+            variable (str): reference variable, Confirmed, Infected, Fatal or Recovered
+            date (str): reference date or None (the last end date in the all scenarios)
+            included (list[str] or None): included scenarios or None (all included)
+            excluded (list[str] or None): excluded scenarios or None (no scenarios not excluded)
+
+        Raises:
+            ValueError: the end dates of the last phase is not aligned
+
+        Returns:
+            list[float] or float: the nearest scenarios which has the values at the given quantiles
+
+        Note:
+            Dimension of returned object corresponds to the type of @q.
+        """
+        quantiles = [q] if isinstance(q, float) else self._ensure_list(q, name="q")
+        variable = self._ensure_selectable(variable, candidates=self.VALUE_COLUMNS, name="variable")
+        # Target scenarios to represent
+        all_set = set(self._tracker_dict.keys())
+        in_set = all_set if included is None else set(self._ensure_list(included, name="included"))
+        ex_set = set() if excluded is None else set(self._ensure_list(excluded, name="excluded"))
+        scenarios = list(all_set & (in_set) - ex_set)
+        # Get simulation data of the variable of the target scenarios
+        sim_dict = {name: self._tracker_dict[name].simulate().set_index(self.DATE)[variable] for name in scenarios}
+        sim_df = pd.DataFrame(sim_dict)
+        if sim_df.isna().to_numpy().sum():
+            raise ValueError(
+                "The end dates of the last phases must be aligned. Scenario.adjust_end() method may fix this issue.")
+        # Find representative scenario
+        date_obj = self._ensure_date(target=date, name="date", default=sim_df.index[-1])
+        series = sim_df.loc[sim_df.index == date_obj].squeeze()
+        values = series.quantile(q=quantiles, interpolation="nearest")
+        return [series[series == v].index.tolist()[0] for v in values]
