@@ -19,32 +19,48 @@ class CleaningBase(Term):
 
     Args:
         filename (str or None): CSV filename of the dataset
-        citation (str or None): citation
+        data (pandas.DataFrame or None):
+            Index
+                reset index
+            Columns
+                - Date: Observation date
+                - ISO3: ISO3 code (optional)
+                - Country: country/region name
+                - Province: province/prefecture/state name
+                - Confirmed: the number of confirmed cases
+                - Fatal: the number of fatal cases
+                - Recovered: the number of recovered cases
+                - Population: population values (optional)
+        citation (str or None): citation or None (empty)
+        variables (list[str] or None): variables to clean (not including date and location identifiers)
 
     Note:
-        - If @filename is None, empty dataframe will be set as raw data and geometry information will be saved in "input" directory.
+        Either @filename (high priority) or @data must be specified.
+
+    Note:
+        - If @filename is None, geometry information will be saved in "input" directory.
         - If @filename is not None, geometry information will be saved in the directory which has the file.
         - The directory of geometry information could be changed with .directory property.
-        - If @citation is None, citation will be empty string.
     """
 
-    def __init__(self, filename, citation=None):
-        warnings.simplefilter("ignore", DeprecationWarning)
-        if filename is None:
-            self._raw = pd.DataFrame()
-            self._cleaned_df = pd.DataFrame()
-        else:
-            Path(filename).parent.mkdir(exist_ok=True, parents=True)
-            self._raw = pd.read_csv(filename, dtype={"Province/State": "object"})
-            self._cleaned_df = self._cleaning()
+    def __init__(self, filename=None, data=None, citation=None, variables=None):
+        # Columns of self._raw, self._clean_df and self.cleaned()
+        self._raw_cols = [self.DATE, self.ISO3, self.COUNTRY, self.PROVINCE] + (variables or [])
+        self._subset_cols = [self.DATE] + (variables or [])
+        # Raw data
+        self._raw = self._parse_raw(filename, data, self._raw_cols)
+        # Data cleaning
+        self._cleaned_df = pd.DataFrame(columns=self._raw_cols) if self._raw.empty else self._cleaning()
+        # Citation
         self._citation = citation or ""
         # Directory that save the file
         if filename is None:
             self._dirpath = Path("input")
         else:
+            Path(filename).parent.mkdir(exist_ok=True, parents=True)
             self._dirpath = Path(filename).resolve().parent
 
-    def _parse_raw(self, filename, data, required_cols, optional_cols=None):
+    def _parse_raw(self, filename, data, columns):
         """
         Parse raw data with a CSV file or a dataframe.
 
@@ -55,8 +71,7 @@ class CleaningBase(Term):
                     reset index
                 Columns
                     columns defined by @required_cols
-            required_cols (list[str]): required columns to parse
-            optional_cols (list[str] or None): optional columns to parse or None (no optinal columns)
+            columns (list[str]): column names to use
 
         Returns:
             pandas.DataFrame:
@@ -69,27 +84,17 @@ class CleaningBase(Term):
             Either @filename (high priority) or @data must be specified.
 
         Note:
-            When some optional columns are not included, None will be registered.
+            If some columns are not included in the dataset, values will be None.
         """
-        all_columns = [*required_cols, *(optional_cols or [])]
         if filename is None:
             if data is None:
-                return pd.DataFrame(columns=all_columns)
-            raw = self._ensure_dataframe(data, name="data")
-        else:
-            raw = self.load(
-                filename, columns=None,
-                dtype={
-                    self.PROVINCE: "object", "Province/State": "object",
-                    "key": "object", "key_alpha_2": "object"
-                }
-            )
-        df = self._ensure_dataframe(raw, name="loaded data", columns=required_cols)
-        if optional_cols is None:
-            return df
-        for col in optional_cols:
-            df[col] = raw.loc[:, col] if col in raw else None
-        return df.loc[:, all_columns]
+                return pd.DataFrame(columns=columns)
+            return data.reindex(columns=columns)
+        dtype_dict = {
+            self.PROVINCE: "object", "Province/State": "object",
+            "key": "object", "key_alpha_2": "object"
+        }
+        return pd.read_csv(filename, dtype=dtype_dict).reindex(columns=columns)
 
     @property
     def raw(self):
@@ -117,6 +122,7 @@ class CleaningBase(Term):
         self._dirpath = Path(name)
 
     @staticmethod
+    @deprecate(".load()", version="2.21.0-kappa-fu5")
     def load(urlpath, header=0, columns=None, dtype="object"):
         """
         Load a local/remote file.
@@ -466,9 +472,12 @@ class CleaningBase(Term):
         df = df.loc[df[self.COUNTRY] != self.OTHERS]
         # Recognize province as a region/country
         if self.PROVINCE in df:
-            df[self.ISO3] = df[self.ISO3].cat.add_categories(["GRL"])
-            df[self.COUNTRY] = df[self.COUNTRY].cat.add_categories(["Greenland"])
-            df.loc[df[self.PROVINCE] == "Greenland", self.AREA_ABBR_COLS] = ["GRL", "Greenland", self.UNKNOWN]
+            try:
+                df[self.ISO3] = df[self.ISO3].cat.add_categories(["GRL"])
+                df[self.COUNTRY] = df[self.COUNTRY].cat.add_categories(["Greenland"])
+                df.loc[df[self.PROVINCE] == "Greenland", self.AREA_ABBR_COLS] = ["GRL", "Greenland", self.UNKNOWN]
+            except ValueError:
+                pass
         # Select country level data
         if self.PROVINCE in df.columns:
             df = df.loc[df[self.PROVINCE] == self.UNKNOWN]
