@@ -3,13 +3,13 @@
 
 from pathlib import Path
 import pandas as pd
-from covsirphy.util.error import SubsetNotFoundError
+from covsirphy.util.error import deprecate, SubsetNotFoundError
 from covsirphy.cleaning.cbase import CleaningBase
 
 
 class LinelistData(CleaningBase):
     """
-    Linelist of case reports.
+    Deprecated. Linelist of case reports.
 
     Args:
         filename (str or pathlib.path): CSV filename to save the raw dataset
@@ -49,6 +49,7 @@ class LinelistData(CleaningBase):
         "date_death_or_discharge": OUTCOME_DATE,
     }
 
+    @deprecate("LinelistData()", version="2.21.0-theta")
     def __init__(self, filename, force=False, verbose=1):
         self._filename = filename
         raw_df = self._read_raw(filename, force, verbose)
@@ -77,7 +78,7 @@ class LinelistData(CleaningBase):
             pd.DataFrame: raw dataset
         """
         if Path(filename).exists() and not force:
-            return self.load(filename, columns=list(self.RAW_COL_DICT))
+            return self._parse_raw(filename, None, list(self.RAW_COL_DICT))
         Path(filename).parent.mkdir(exist_ok=True, parents=True)
         return self._retrieve(filename=filename, verbose=verbose)
 
@@ -97,7 +98,7 @@ class LinelistData(CleaningBase):
             print(
                 "Retrieving linelist from Open COVID-19 Data Working Group repository: https://github.com/beoutbreakprepared/nCoV2019")
         # Download the dataset
-        df = self.load(self.URL, header=1, columns=list(self.RAW_COL_DICT))
+        df = pd.read_csv(self.URL, header=1, usecols=list(self.RAW_COL_DICT))
         # Save the raw data
         df.to_csv(filename, index=False)
         return df
