@@ -1,7 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from pathlib import Path
 import numpy as np
 import pandas as pd
 from covsirphy.util.error import deprecate, SubsetNotFoundError
@@ -10,6 +9,7 @@ from covsirphy.cleaning.cbase import CleaningBase
 
 class PopulationData(CleaningBase):
     """
+    Deprecated.
     Data cleaning of total population dataset.
 
     Args:
@@ -28,29 +28,10 @@ class PopulationData(CleaningBase):
     Note:
         Either @filename (high priority) or @data must be specified.
     """
-    # Columns of self._raw and self._clean_df
-    RAW_COLS = [
-        CleaningBase.DATE, CleaningBase.ISO3, CleaningBase.COUNTRY, CleaningBase.PROVINCE, CleaningBase.N]
-    # Columns of self.cleaned()
-    CLEANED_COLS = RAW_COLS[:]
-    # Columns of self.subset()
-    SUBSET_COLS = [CleaningBase.DATE, CleaningBase.N]
-    # Deprecated
-    POPULATION_COLS = RAW_COLS[:]
 
+    @deprecate("PopulationData", new="JHUData", version="2.21.0-xi-fu1")
     def __init__(self, filename=None, data=None, citation=None):
-        # Raw data
-        self._raw = self._parse_raw(filename, data, self.RAW_COLS)
-        # Data cleaning
-        self._cleaned_df = pd.DataFrame(columns=self.RAW_COLS) if self._raw.empty else self._cleaning()
-        # Citation
-        self._citation = citation or ""
-        # Directory that save the file
-        if filename is None:
-            self._dirpath = Path("input")
-        else:
-            Path(filename).parent.mkdir(exist_ok=True, parents=True)
-            self._dirpath = Path(filename).resolve().parent
+        super().__init__(filename=filename, data=data, citation=citation, variables=[self.N])
 
     def _cleaning(self):
         """
@@ -72,9 +53,9 @@ class PopulationData(CleaningBase):
         df[self.DATE] = pd.to_datetime(df[self.DATE])
         # Province
         df[self.PROVINCE] = df[self.PROVINCE].fillna(self.UNKNOWN)
-        df[self.N] = df[self.N].astype(np.int64)
+        df[self.N] = df[self.N].fillna(0).astype(np.int64)
         # Columns to use
-        df = df.loc[:, self.CLEANED_COLS]
+        df = df.loc[:, self._raw_cols]
         # Remove duplicates
         df = df.dropna(subset=[self.N]).drop_duplicates().reset_index(drop=True)
         # Update data types to reduce memory
@@ -166,7 +147,7 @@ class PopulationData(CleaningBase):
             self._cleaned_df = df.copy()
             return self
         series = pd.Series(
-            [date_stamp, self.UNKNOWN, country, province, population], index=self.CLEANED_COLS)
+            [date_stamp, self.UNKNOWN, country, province, population], index=self._raw_cols)
         self._cleaned_df = df.append(series, ignore_index=True)
         return self
 
