@@ -7,8 +7,6 @@ import numpy as np
 from optuna.exceptions import ExperimentalWarning
 import pandas as pd
 from sklearn.exceptions import ConvergenceWarning
-from sklearn.model_selection import train_test_split
-from covsirphy.util.argument import find_args
 from covsirphy.util.evaluator import Evaluator
 from covsirphy.util.term import Term
 from covsirphy.regression.reg_pred_actual_plot import _PredActualPlot
@@ -19,85 +17,28 @@ class _RegressorBase(Term):
     Basic class to predict parameter values of ODE models.
 
     Args:
-        X (pandas.DataFrame):
-            Index
-                Date (pandas.Timestamp): observation date
-            Columns
-                (int/float): indicators
-        y (pandas.DataFrame):
-            Index
-                Date (pandas.Timestamp): observation date
-            Columns
-                (int/float) target values
-        delay_values (list[int]): list of delay period [days]
-        kwargs: keyword arguments of sklearn.model_selection.train_test_split(test_size=0.2, random_state=0)
-
-    Note:
-        If @seed is included in kwargs, this will be converted to @random_state.
+        - X_train (pandas.DataFrame): X for training with time index
+        - X_test (pandas.DataFrame): X for test with time index
+        - Y_train (pandas.DataFrame): Y for training with time index
+        - Y_test (pandas.DataFrame): Y for test with time index
+        - X_target (pandas.DataFrame): X for prediction with time index
     """
     warnings.simplefilter("ignore", category=ConvergenceWarning)
     warnings.simplefilter("ignore", category=ExperimentalWarning)
     # Description of regressor
     DESC = ""
 
-    def __init__(self, X, y, delay_values, **kwargs):
-        # Validate values
-        self._ensure_dataframe(X, name="X", time_index=True)
-        self._ensure_dataframe(y, name="y", time_index=True)
-        self._delay_values = [self._ensure_natural_int(v) for v in self._ensure_list(delay_values)]
-        # Set training/test dataset
-        splitted_all = self._split(X, y, self._delay_values, **kwargs)
-        self._X_train, self._X_test, self._y_train, self._y_test, self._X_target = splitted_all
+    def __init__(self, X_train, X_test, Y_train, Y_test, X_target):
+        # Datasets
+        self._X_train, self._X_test = X_train.copy(), X_test.copy()
+        self._Y_train, self._Y_test = Y_train.copy(), Y_test.copy()
+        self._X_target = X_target.copy()
         # Regression model
         self._pipeline = None
         self._param = {}
         # Perform fitting
         self._fit()
 
-    @staticmethod
-    def _split(X, y, delay_values, **kwargs):
-        """
-        Add delayed indicator values to X and split X and y to train/test data.
-
-        Args:
-            X (pandas.DataFrame): indicators with time index
-            y (pandas.DataFrame): target values with time index
-            delay_values (list[int]): list of delay period [days]
-            kwargs: keyword arguments of sklearn.model_selection.train_test_split()
-
-        Returns:
-            tuple(pandas.DataFrame): datasets with time index
-                - X_train
-                - X_test
-                - y_train
-                - y_test
-                - X_target
-
-        Note:
-            If @seed is included in kwargs, this will be converted to @random_state.
-
-        Note:
-            default values regarding sklearn.model_selection.train_test_split() are
-            test_size=0.2, random_state=0, shuffle=False.
-        """
-        split_kwargs = {"test_size": 0.2, "random_state": 0, "shuffle": False}
-        split_kwargs.update(kwargs)
-        split_kwargs["random_state"] = split_kwargs.get("seed", split_kwargs["random_state"])
-        split_kwargs = find_args(train_test_split, **split_kwargs)
-        # Add delayed indicator values to X
-        X_delayed = X.copy()
-        for delay in delay_values:
-            X_delayed = X_delayed.join(X.shift(delay, freq="D"), how="outer", rsuffix=f"_{delay}")
-        X_delayed = X_delayed.ffill()
-        # Training/test data
-        df = X_delayed.join(y, how="inner").dropna().drop_duplicates()
-        X_arranged = df.loc[:, X_delayed.columns]
-        y_arranged = df.loc[:, y.columns]
-        splitted = train_test_split(X_arranged, y_arranged, **split_kwargs)
-        # X_target
-        X_target = X_delayed.loc[X_delayed.index > y.index.max()]
-        return (*splitted, X_target)
-
     def _fit(self):
         """
         Fit regression model with training dataset, update self._pipeline and self._param.
@@ -115,8 +56,8 @@ class _RegressorBase(Term):
         Returns:
             float: evaluation score
         """
-        pred_train = pd.DataFrame(self._pipeline.predict(self._X_train), columns=self._y_train.columns)
-        return Evaluator(pred_train, self._y_train, how="all").score(metric=metric)
+        pred_train = pd.DataFrame(self._pipeline.predict(self._X_train), columns=self._Y_train.columns)
+        return Evaluator(pred_train, self._Y_train, how="all").score(metric=metric)
 
     def score_test(self, metric):
         """
@@ -128,8 +69,8 @@ class _RegressorBase(Term):
         Returns:
             float: evaluation score
         """
-        pred_test = pd.DataFrame(self._pipeline.predict(self._X_test), columns=self._y_test.columns)
-        return Evaluator(pred_test, self._y_test, how="all").score(metric=metric)
+        pred_test = pd.DataFrame(self._pipeline.predict(self._X_test), columns=self._Y_test.columns)
+        return Evaluator(pred_test, self._Y_test, how="all").score(metric=metric)
 
     def to_dict(self, metric):
         """
@@ -155,19 +96,18 @@ class _RegressorBase(Term):
             "score_metric": metric,
             "score_train": self.score_train(metric=metric),
             "score_test": self.score_test(metric=metric),
-            "delay": self._delay_values,
             "dataset": {
                 "X_train": self._X_train,
-                "y_train": self._y_train,
+                "y_train": self._Y_train,
                 "X_test": self._X_test,
-                "y_test": self._y_test,
+                "y_test": self._Y_test,
                 "X_target": self._X_target,
             }
         }
 
     def predict(self):
         """
-        Predict parameter values (via y) with self._pipeline and X_target.
+        Predict parameter values (via Y) with self._pipeline and X_target.
 
         Returns:
             pandas.DataFrame:
@@ -178,7 +118,7 @@ class _RegressorBase(Term):
         """
         # Predict parameter values
         predicted = self._pipeline.predict(self._X_target)
-        df = pd.DataFrame(predicted, index=self._X_target.index, columns=self._y_train.columns)
+        df = pd.DataFrame(predicted, index=self._X_target.index, columns=self._Y_train.columns)
         # parameter values: 4 digits
         return df.applymap(lambda x: self._round(x, digits=4))
 
@@ -228,16 +168,16 @@ class _RegressorBase(Term):
         train_title = f"Training data (n={len(self._X_train)}, {metric}={train_score_str})"
         test_title = f"Test data (n={len(self._X_test)}, {metric}={test_score_str})"
         # Predicted & training
-        pred_train = pd.DataFrame(self._pipeline.predict(self._X_train), columns=self._y_train.columns)
+        pred_train = pd.DataFrame(self._pipeline.predict(self._X_train), columns=self._Y_train.columns)
         pred_train["subset"] = train_title
         # Predicted & test
-        pred_test = pd.DataFrame(self._pipeline.predict(self._X_test), columns=self._y_test.columns)
+        pred_test = pd.DataFrame(self._pipeline.predict(self._X_test), columns=self._Y_test.columns)
         pred_test["subset"] = test_title
         # Actual & training
-        act_train = self._y_train.copy()
+        act_train = self._Y_train.copy()
         act_train["subset"] = train_title
         # Actual & test
-        act_test = self._y_train.copy()
+        act_test = self._Y_train.copy()
         act_test["subset"] = test_title
         # Combine data: index=reset, columns=parameter/subset/Predicted/Actual
         df = pd.concat([pred_train, pred_test], ignore_index=True)
